function [Outconfig]=CoordinatesPlot(InCellArray, Inconfig)
%CoordinatesPlot plots 2D and 3D Coordinates data.
%
%Inputs: Coordinates
%Outputs: Plot, TriMesh plot, GridMesh Plot, or Surface plot
%
%Author: Won Hyun Park
%Email: nova8028@gmail.com, whpark@optics.arizona.edu
%
% Version history:
% 9/29/10 - Version 1.0
% 8/17/11 - Version 1.1 by Dae Wook Kim (letter2dwk@hotmail.com) add x,y,z
% labels
% 11/29/11 - Version 1.2 Benjamin Lewis blewis@email.arizona.edu (Added
% support for new units types, and added a gui for selection of plot type
% 1/12/12 - Version 1.3 Benjamin Lewis blewis@email.arizona.edu (Added
% support for 2D plots)

Outconfig=Inconfig;

data = InCellArray{1}.data;
figure;

if size(data,2)==2
    plot(data(:,1),data(:,2));    
    
    labels=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Column label'),2};
    
    labels=regexp(labels,', ','split');
    
    units=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Column unit'),2};
    
    units=regexp(units,', ','split');
    
    xlabel([labels{1},' (',units{1},')']);
    ylabel([labels{2},' (',units{2},')']);
    
    
elseif size(data,2)==3    
    b=questdlg('Please Select Plot Type:','CoordinatesPlot','Trimesh','Gridmesh','Surface',Outconfig{strcmpi(Outconfig, 'Plot type'),2});
    
    switch b
        case 'Trimesh'
            tri=delaunay(data(:,1),data(:,2));
            trimesh(tri,data(:,1),data(:,2),data(:,3));
        case 'Gridmesh'
            F = TriScatteredInterp(data(:,1),data(:,2),data(:,3));
            dx = linspace(min(data(:,1)),max(data(:,1)),101);
            dy = linspace(min(data(:,2)),max(data(:,2)),101);
            [newx,newy] = meshgrid(dx,dy);
            newz = F(newx,newy);
            mesh(newx,newy,newz);
        case 'Surface'
            tri=delaunay(data(:,1),data(:,2));
            trisurf(tri,data(:,1),data(:,2),data(:,3));shading interp;
            %     otherwise
            %             errordlg('Please select plot type. 0:TriMesh, 1:GridMesh, 2:Surface');
            %             return;
    end
    
    Outconfig{strcmpi(Outconfig, 'Plot Type'),2}=b;
    
    
    b=questdlg('Show Original Data?','CoordinatesPlot','on','off',Outconfig{strcmpi(Outconfig, 'Original data'),2});
    
    switch b
        case 'on'
            hold on;plot3(data(:,1),data(:,2),data(:,3),'.');
        case 'off'
            %     otherwise
            %         errordlg({'Please type on or off for showing or hiding original data'});
    end
    
    Outconfig{strcmpi(Outconfig, 'Original data'),2}=b;
    
    
    hold off;colorbar;
    
    
    labels=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Column label'),2};
    
    labels=regexp(labels,', ','split');
    
    units=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Column unit'),2};
    
    units=regexp(units,', ','split');
    
    xlabel([labels{1},' (',units{1},')']);
    ylabel([labels{2},' (',units{2},')']);
    zlabel([labels{3},' (',units{3},')']);
    
else
    return;
end



