function [OutCellArray, Outconfig]=FreqMapIFFT(InCellArray, Inconfig)
%MapIFFT takes the inverse fourier transform of a 2D frequency map and the
%input is a rectangular array.
%
% NOTE: Values returned from this module are obtained after normalizing by
% the area of the frequency map. To get true IFFT values, multiply by the area of the
% input freqmap in the appropriate units.
%
%Inputs: Frequency Map
%Outputs: Map
%
%Author: Ping Zhou
%Email:
%
% Version history:
% 9/9/10 - Version 1
% 6/21/12 - Version 3 - G. Smith - normalized output to keep units simple

OutCellArray{1}=InCellArray{1};
OutCellArray{1}.type='map';

% Pings original code
% OutCellArray{1}.header{strcmpi(OutCellArray{1}.header, 'Max Frequency (1/mm)'),1}='Half Width (mm)';
% MaxFreq = str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Max Frequency (1/mm)'),2});
% pts = str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Data Points'),2});
% delf = 2*MaxFreq/pts;
% radius = 1/(2*delf);
% OutCellArray{1}.header{strcmpi(OutCellArray{1}.header, 'Half Width (mm)'),2}=num2str(radius);
% delx = 2*radius/pts;

x_max_freq=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Max Frequency'),2});
%display(x_max_freq);
y_max_freq=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Max Frequency'),2});
xunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Unit'),2};
xunit=strrep(xunit, '1/', '');
yunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Unit'),2};
yunit=strrep(yunit, '1/', '');
zunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Z Unit'),2};


%New Code
x_pts = size(InCellArray{1}.data, 2);

y_pts = size(InCellArray{1}.data, 1);

x_size=x_pts/(2*x_max_freq);

y_size=y_pts/(2*y_max_freq);


delx = x_size/x_pts;

dely = y_size/y_pts;
%End New Code


% x_size = size(InCellArray{1}.data, 2);
% 
% y_size = size(InCellArray{1}.data, 1);
% 
% 
% delx = 1/(2*x_max_freq*x_size);
% 
% dely = 1/(2*y_max_freq*y_size);


OutCellArray{1}.header = [];
OutCellArray{1}.header={'Date Created', ''};

OutCellArray{1}.header(end+1, :)={'X Size', num2str(x_size)};
OutCellArray{1}.header(end+1, :)={'Y Size', num2str(y_size)};

OutCellArray{1}.header(end+1,:)={'X unit', xunit};
OutCellArray{1}.header(end+1,:)={'Y unit', yunit};
OutCellArray{1}.header(end+1,:)={'Z unit', zunit};

Outconfig=Inconfig;

data = InCellArray{1}.data;
data(isnan(data))=0;

% G = ifftshift(ifft2(ifftshift(data)/delx/dely)); % ping's original code
G=ifft2(ifftshift(data))/delx/dely;

% G.S. - 2012/06/21 - divide by area of freqmap to keep output units simple
OutCellArray{1}.data=real(G)/4/x_max_freq/y_max_freq*size(data,1)*size(data,2);