function [OutCellArray, Outconfig]=MapFFT(InCellArray, Inconfig)
%MapFFT takes the fourier transform of a 2D map and the input is a 2D
%rectangular array.
%
% NOTE: Values returned from this module are obtained after normalizing by
% the area of the map. To get true FFT values, multiply by the area of the
% input map in the appropriate units.
%
%Inputs: Map
%Outputs: FreqMap
%
%Author: Ping Zhou, Michael Palmer
%Email: mikeppalmer@gmail.com
%
% Version history:
% 9/9/10 - Version 1 - Ping Zhou
% 11/10/11 - Version 2 - Michael Palmer
% 6/21/12 - Version 3 - Greg Smith - normalized output to keep units simple

OutCellArray{1}=InCellArray{1};
OutCellArray{1}.type='freqmap';


xsize=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Size'),2};
ysize=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Size'),2};

xunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Unit'),2};
yunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Unit'),2};
zunit=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Z Unit'),2};

OutCellArray{1}.header = [];
OutCellArray{1}.header={'Date Created', ''};

OutCellArray{1}.header(end+1,:)={'X unit', ['1/', xunit]};
OutCellArray{1}.header(end+1,:)={'Y unit', ['1/', yunit]};
OutCellArray{1}.header(end+1,:)={'Z unit', zunit};

xsize = str2double(xsize);
delx = xsize/size(InCellArray{1}.data, 2);          % size of each pixel in x-direction
xsize = 1/(2*delx);                                 % max frequency in x direction

OutCellArray{1}.header(end+1,:)={'X Max Frequency', num2str(xsize)};

ysize = str2double(ysize);
dely = ysize/size(InCellArray{1}.data, 1);
ysize = 1/(2*dely);

OutCellArray{1}.header(end+1,:)={'Y Max Frequency', num2str(ysize)};


Outconfig=Inconfig;

data = InCellArray{1}.data;

data(isnan(data))=0;

G = delx*dely*fftshift(fft2(data));

% G.S. - 2012/06/21 - divide by area of map to keep output units simple
xsize=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'X Size'),2});
ysize=str2double(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'Y Size'),2});
OutCellArray{1}.data=G/xsize/ysize;

