function [OutCellArray, Outconfig]=RadiallyAvg2Coords(InCellArray, Inconfig)
%This module converts a map into a radially average section.
%
%Inputs: Map
%Outputs: Coordinates
%
%Author: Benjamin Lewis
%Email: blewis@email.arizona.edu
%
% Version history:
% 7/28/10 - Version 1
% 1/12/12 - Version 2 (Added support for new datatypes, algorithm tweaks)

Outconfig=Inconfig;

OutCellArray{1}=InCellArray{1};

xs=str2num(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'x size'),2});
ys=str2num(InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'y size'),2});

xu=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'x unit'),2};
yu=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'y unit'),2};
zu=InCellArray{1}.header{strcmpi(InCellArray{1}.header, 'z unit'),2};

if ~strcmpi(xu,yu)
    h=msgbox('Unit Missmatch in X and Y, X unit will be used.','RadiallyAvg2Coords Error','Warn','modal');
    uiwait(h);
end


OutCellArray{1}.type='coordinates';

OutCellArray{1}.header={'Date Created', ''; 'Column Unit', [xu,', ',zu]; 'Column Label', 'Rho, Z'};

dmap=InCellArray{1}.data;




x=linspace(-.5, .5, size(dmap,2));
y=linspace(-.5, .5, size(dmap,1));
[x,y]=meshgrid(x*xs,-1*y*ys);
[~, rho] = cart2pol(x,y);

%compute radial cordinate pairs
rho(isnan(InCellArray{1}.data))=NaN;

radmap=[InCellArray{1}.data(:), rho(:)];
radmap(isnan(radmap(:,1)),:)=[];
radmap=sortrows(radmap,2);

rhovec=radmap(:,2);
zvec=radmap(:,1);

indx=1;
curr_rho=rhovec(1);

ivec=zeros(length(rhovec),1);
ivec(1)=1;

tolerance=1e-3*max(rhovec); %tolerance for binning

for ii=2:length(rhovec) %bin z data, according to rho values
    if abs(rhovec(ii)-curr_rho)<tolerance
        ivec(ii)=indx;
    else
        indx=indx+1;
        ivec(ii)=indx;
        curr_rho=rhovec(ii);
    end    
end

orhovec=[];
ozvec=[];

for ii=1:max(ivec) %for each bin, use the median value to compute rho and z
    orhovec(ii)=median(rhovec(ivec==ii));
    ozvec(ii)=median(zvec(ivec==ii));
end

for ii=1:length(ozvec) %median filter the results to remove noise
    nhood=ozvec(max(ii-1,1):min(length(ozvec),ii+1));
    ozvec(ii)=median(nhood);
end

fsize=5; %low-pass filter the results to remove noise

ozvec=conv(ozvec,ones(1,fsize),'same')./conv(ones(1,length(ozvec)),ones(1,fsize),'same');




OutCellArray{1}.data=[orhovec;ozvec]';



% numsum=1;
% 
% ii=2;
% 
% tolerance=.00001;
% 
% while ii<=size(radmap, 1) %averaging
%     if abs(radmap(ii,2)-radmap(ii-1,2))<tolerance %rho is same, so average
%         numsum=numsum+1;
%         radmap(ii-1,1)=radmap(ii-1,1)+radmap(ii,1);
%         radmap(ii,:)=[];
%     else %rho different, so start new point
%         radmap(ii-1,1)=radmap(ii-1,1)/numsum;
%         numsum=1;
%         ii=ii+1;
%     end
% end
% 
% radmap(end,1)=radmap(end,1)/numsum; %Take care of last datapoint, which doesn't get handled in while loop
% 
% rhomax=max(radmap(:,2));
% rhomin=min(radmap(:,2));
% 
% rhopts=ceil(str2num(pts)/2)*(rhomax-rhomin); %Preserve sample spacing;
% 
% rhovec=linspace(rhomin, rhomax, rhopts);
% 
% avgprof=radmap(:,1);
% avgprof=interp1(radmap(:,2), avgprof, rhovec, 'spline'); %interpolate back to even sample spacing
% 
% OutCellArray{1}.data=avgprof;

end






