function [OutCellArray,Outconfig]=TwoDifferentInputs(InCellArray, Inconfig)
% TWODIFFERENTINPUTS is a template module that takes two data types as input.
%
% TwoDifferentInputs does not perform any action. It is intended to show an
% example of a module which can operate on two different data types as
% inputs. In this example, the types are 'map' data type and a 'mask' data
% type. The output of this template module will be the same data type as
% the 'map' input data type.
%
% Note: This module will NOT APPEAR IN SAGUARO. To practice using it, place
% a copy of the .m file and the associated .txt file in the 'UserModules'
% directory. To activate it within SAGUARO, a mask and a map data set must
% be selected simultaneously. This can be accomplished by holding down the
% <Ctrl> key while selecting two previously loaded/generated data sets.
%
% Note: The associated TwoDifferentInputs.txt file contains the following
% lines which are at the heart of this module functionality:
%                   Mask&Map, 2, General
%                   %parameter=1
% The first line specifies the data types that are input. The second line
% describes an additional input parameter needed for the calculation.
%
% On the first line, the 'Mask&Map' portion describes the two data types
% need for input (in this case a 'Mask' data type and a 'Map' data type).
% In general, when dealing with multiple different data types, they should
% always be listed with an ampersand symbol (&) between them. For instance,
% a module which required a 'coordinates', a 'frequency map' and a 'mask'
% would have something like: 'Coordinates&FreqMap&Mask'.
%
% The order of the input datatypes does not matter. When used inside the
% function, they are provided alphabetically. The strings are case
% insensitive. Thus even though the line says 'Mask&Map', the first data
% set will always be the 'Map' data type and the second will always be the
% 'Mask', independent of how they are selected by the user.
%
% The second value on the first line describes the total number of input
% datasets. In this example, there are two data sets.
%
% The third value in the first line of the text file describes the category
% the module fits into. In this case, the module can be found under the
% 'General' category. This categorization is useful for quickly finding
% modules in SAGUARO by using the sort feature.
%
% As stated earlier, the second line of the test file denote module
% configuration parameters. These lines always start with a '%' symbol.
% Additional lines can be added for each parameter needed. Each line can
% only contain one configuration parameter
%
% Inputs: One 'map' datatype and one 'mask' data type
% Outputs: one 'map' data type
%
% Author: Greg Smith
% Email: gsmith@optics.arizona.edu
%
% Version history:
% 2012/06/20 - Version 1.0

% default values will be set to the first data type provided
% Since 'map' comes before 'mask' alphabetically, the default will be the map data type
Outconfig=Inconfig;
OutCellArray{1}=InCellArray{1};

% extract the two data sets for calculation
% Since 'map' comes before 'mask' alphabetically, the first will always be the map data type
map = InCellArray{1}.data;
mask = InCellArray{2}.data;

% Perform computation
% note: This will generally be more interesting, and should include data
% validation when needed to make sure calculation proceeds without error.
% In this example, the user should ideally be warned if the map and mask
% do not have the same number of elements.
dataOut = map.*mask;


% set output data
OutCellArray{1}.data = dataOut;
end


